# Generated by Django 3.2.7 on 2022-06-14 05:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0002_auto_20220614_0456'),
    ]

    operations = [
        migrations.AddField(
            model_name='purchase',
            name='status',
            field=models.CharField(blank=True, default='pending', max_length=30, null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='status',
            field=models.CharField(blank=True, default='active', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='card',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='card',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='cart',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='cart',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='conversation',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='conversation',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='disco',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='disco',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='document',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='document',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='documentation',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='documentation',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='expertise',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='expertise',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='meansofidentification',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='meansofidentification',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='message',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='message',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='meterrequest',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='meterrequest',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='nextofkin',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='nextofkin',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='payment',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='payment',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='paymenttype',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='paymenttype',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='product',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='product',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='product',
            name='status',
            field=models.CharField(blank=True, default='active', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='purchase',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='purchase',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='survey',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='survey',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='transactionlog',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='transactionlog',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='user',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='user',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='useraddress',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='useraddress',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='verification',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='verification',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='verificationtype',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='verificationtype',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='wallethistory',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='wallethistory',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='workordermaterial',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='workordermaterial',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='workorderservice',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='workorderservice',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='status',
            field=models.CharField(blank=True, default='active', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='workorderstatus',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='workorderstatus',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
    ]



import uuid
from django.conf import settings
from django.db import models
from safedelete.models import SafeDeleteModel
from django.utils import timezone


class BaseModelAbstract(SafeDeleteModel):
    uid = models.UUIDField(default=uuid.uuid4, editable=False)
    createdBy = models.ForeignKey(settings.AUTH_USER_MODEL, models.SET_NULL,
                                  blank=True, null=True)
    
    deleted = models.BooleanField(default=False)
    deletedById = models.UUIDField(blank=True, null=True)
    
    deletedAt = models.DateTimeField(db_column='deletedAt', blank=True,
                                     null=True)
    createdAt = models.DateTimeField(db_column='createdAt',
                                     auto_now_add=True)
    updatedAt = models.DateTimeField(db_column='updatedAt', auto_now=True)
    
    class Meta:
        abstract = True
        ordering = ('-createdAt', )
    
    def save(self, keep_deleted=False, **kwargs):
        if self.uid is None:
            self.uid = uuid.uuid4()
        super(BaseModelAbstract, self).save(keep_deleted, **kwargs)

    def delete(self, by=None, force_policy=None, **kwargs):
        self.deletedBy = by
        self.deleted = True
        super(BaseModelAbstract, self).delete(force_policy, **kwargs)

    def undelete(self, force_policy=None, **kwargs):
        self.deletedBy = None
        self.deleted = False
        super(BaseModelAbstract, self).undelete(force_policy, **kwargs)


# class BaseModel(BaseModelAbstract, models.Model):
#     pass



# Generated by Django 3.2.7 on 2022-06-13 15:15

from django.conf import settings
import django.contrib.auth.models
import django.contrib.auth.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import mojec_core.app.models.base


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('username', models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=150, unique=True, validators=[django.contrib.auth.validators.UnicodeUsernameValidator()], verbose_name='username')),
                ('is_staff', models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
                ('date_joined', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined')),
                ('email', models.EmailField(max_length=254, unique=True)),
                ('name', models.CharField(max_length=255)),
                ('phoneNumber', models.CharField(blank=True, db_column='phoneNumber', max_length=11, null=True, unique=True)),
                ('emailVerified', models.BooleanField(blank=True, db_column='emailVerified', null=True)),
                ('phoneNumberVerified', models.BooleanField(blank=True, db_column='phoneNumberVerified', null=True)),
                ('verified', models.BooleanField(blank=True, null=True)),
                ('verificationMode', models.CharField(blank=True, db_column='verificationMode', max_length=255, null=True)),
                ('platform', models.CharField(blank=True, max_length=15, null=True)),
                ('active', models.BooleanField(blank=True, null=True)),
                ('bankAccountNumber', models.CharField(blank=True, db_column='bankAccountNumber', max_length=11, null=True)),
                ('isOnboardingComplete', models.BooleanField(db_column='isOnboardingComplete', default=False)),
                ('onboardingStage', models.CharField(blank=True, db_column='onboardingStage', max_length=100, null=True)),
                ('imageUrl', models.TextField(blank=True, db_column='imageUrl', null=True)),
                ('bankAccountName', models.CharField(blank=True, db_column='bankAccountName', max_length=255, null=True)),
                ('bvn', models.CharField(blank=True, max_length=11, null=True)),
                ('bankCode', models.CharField(blank=True, db_column='bankCode', max_length=10, null=True)),
                ('sbcId', models.UUIDField(blank=True, null=True)),
                ('fcmToken', models.JSONField(blank=True, db_column='fcmToken', null=True)),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.Group', verbose_name='groups')),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions')),
            ],
            options={
                'db_table': 'Users',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
            managers=[
                ('objects', django.contrib.auth.models.UserManager()),
            ],
        ),
        migrations.CreateModel(
            name='Cart',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('totalAmount', models.DecimalField(db_column='totalAmount', decimal_places=2, default=0, max_digits=15)),
                ('status', models.TextField(blank=True, null=True)),
                ('transactionRef', models.CharField(blank=True, db_column='transactionRef', max_length=255, null=True)),
                ('deliveryAddress', models.TextField(blank=True, db_column='deliveryAddress', null=True)),
            ],
            options={
                'db_table': 'Carts',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Conversation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('participants', models.ManyToManyField(blank=True, null=True, related_name='conversations', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'Conversations',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Disco',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
                ('location', models.TextField(blank=True, null=True)),
                ('status', models.CharField(blank=True, max_length=30, null=True)),
            ],
            options={
                'db_table': 'Discos',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='MeansOfIdentification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('active', models.BooleanField(default=True)),
            ],
            options={
                'db_table': 'MeansOfIdentifications',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='PaymentType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(blank=True, max_length=255, null=True)),
                ('path', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'PaymentTypes',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='PaymentVendor',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(blank=True, max_length=255, null=True)),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('accountNo', models.CharField(blank=True, db_column='accountNo', max_length=255, null=True)),
                ('accountName', models.CharField(blank=True, db_column='accountName', max_length=255, null=True)),
                ('paths', models.CharField(blank=True, max_length=255, null=True)),
                ('ref', models.CharField(blank=True, max_length=255, null=True)),
                ('logo', models.CharField(blank=True, max_length=255, null=True)),
                ('credential', models.JSONField()),
                ('url', models.URLField()),
            ],
            options={
                'db_table': 'PaymentVendors',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('productName', models.CharField(max_length=255)),
                ('description', models.CharField(max_length=255)),
                ('quantity', models.IntegerField(default=1)),
                ('price', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('status', models.CharField(blank=True, max_length=30, null=True)),
            ],
            options={
                'db_table': 'Products',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='UserAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
                ('text', models.TextField()),
            ],
            options={
                'abstract': False,
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='VerificationType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('active', models.BooleanField(blank=True, null=True)),
            ],
            options={
                'db_table': 'VerificationTypes',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Wallet',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('recipientCode', models.CharField(blank=True, db_column='recipientCode', max_length=255, null=True)),
                ('recipient', models.JSONField(blank=True, null=True)),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('balance', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='wallet', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'Wallets',
            },
        ),
        migrations.CreateModel(
            name='WorkOrder',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.TextField(blank=True, null=True)),
                ('orderId', models.CharField(db_column='orderId', max_length=30)),
                ('assessmentReport', models.TextField(blank=True, db_column='assessmentReport', null=True)),
                ('completionReport', models.TextField(blank=True, db_column='completionReport', null=True)),
                ('transactionReference', models.TextField(blank=True, db_column='transactionReference', null=True)),
                ('generalStatus', models.TextField(blank=True, db_column='generalStatus', null=True)),
                ('noteForAgent', models.TextField(blank=True, db_column='noteForAgent', null=True)),
                ('additionalNote', models.TextField(blank=True, db_column='additionalNote', null=True)),
                ('date', models.DateTimeField()),
                ('fee', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('totalAmount', models.DecimalField(db_column='totalAmount', decimal_places=2, default=0, max_digits=15)),
                ('actualServiceCharge', models.DecimalField(db_column='actualServiceCharge', decimal_places=2, default=0, max_digits=15)),
                ('remainingServiceCharge', models.DecimalField(db_column='remainingServiceCharge', decimal_places=2, default=0, max_digits=15)),
                ('remainingtotalAmount', models.DecimalField(db_column='remainingtotalAmount', decimal_places=2, default=0, max_digits=15)),
                ('totalMaterialsFee', models.DecimalField(db_column='totalMaterialsFee', decimal_places=2, default=0, max_digits=15)),
                ('isCommitmentFeePaid', models.BooleanField(blank=True, db_column='isCommitmentFeePaid', null=True)),
                ('agentEnroute', models.BooleanField(blank=True, db_column='agentEnroute', null=True)),
                ('agentArrived', models.BooleanField(blank=True, db_column='agentArrived', null=True)),
                ('isAssessmentCompleted', models.BooleanField(blank=True, db_column='isAssessmentCompleted', null=True)),
                ('paymentCompleted', models.BooleanField(blank=True, db_column='paymentCompleted', null=True)),
                ('jobStartedAt', models.DateTimeField(blank=True, db_column='jobStartedAt', null=True)),
                ('jobCompletedAt', models.DateTimeField(blank=True, db_column='jobCompletedAt', null=True)),
                ('isAgentJobComplete', models.BooleanField(blank=True, db_column='isAgentJobComplete', null=True)),
                ('customerCompletionConfirmation', models.BooleanField(blank=True, db_column='customerCompletionConfirmation', null=True)),
                ('isAgentReview', models.BooleanField(db_column='isAgentReview', default=False)),
                ('isCustomerReview', models.BooleanField(db_column='isCustomerReview', default=False)),
                ('paymentJson', models.TextField(blank=True, db_column='paymentJson', null=True)),
                ('agentEnrouteAt', models.DateTimeField(blank=True, db_column='agentEnrouteAt', null=True)),
                ('agentArrivedAt', models.DateTimeField(blank=True, db_column='agentArrivedAt', null=True)),
                ('address', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.useraddress')),
                ('agent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='workorders_agent_set', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'WorkOrders',
            },
        ),
        migrations.CreateModel(
            name='WorkOrderService',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'WorkOrderServices',
            },
        ),
        migrations.CreateModel(
            name='WorkOrderStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(blank=True, max_length=50, null=True)),
                ('currentStatus', models.BooleanField(db_column='currentStatus', default=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('workOrder', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder')),
            ],
            options={
                'db_table': 'WorkOrderStatuses',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='WorkOrderServiceCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.TextField(blank=True, null=True)),
                ('chargeType', models.TextField(blank=True, db_column='chargeType', null=True)),
                ('commission', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('serviceCharge', models.DecimalField(db_column='serviceCharge', decimal_places=2, default=0, max_digits=15)),
                ('commitmentFee', models.DecimalField(db_column='commitmentFee', decimal_places=2, default=0, max_digits=15)),
                ('status', models.CharField(blank=True, max_length=100, null=True)),
                ('serviceId', models.ForeignKey(blank=True, db_column='serviceId', null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorderservice')),
            ],
            options={
                'db_table': 'WOServiceCategories',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='WorkOrderMaterial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('item', models.UUIDField(blank=True, null=True)),
                ('quantity', models.IntegerField(default=1)),
                ('price', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
                ('productName', models.TextField(blank=True, db_column='productName', null=True)),
                ('workOrder', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder')),
            ],
            options={
                'db_table': 'WorkOrderMaterials',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.AddField(
            model_name='workorder',
            name='serviceSubCategory',
            field=models.ForeignKey(blank=True, db_column='serviceSubCategory', null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorderservicecategory'),
        ),
        migrations.CreateModel(
            name='WalletHistory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
                ('type', models.CharField(blank=True, max_length=30, null=True)),
                ('requestJson', models.JSONField(blank=True, db_column='requestJSON', null=True)),
                ('transferCode', models.CharField(blank=True, db_column='transferCode', max_length=255, null=True)),
                ('isCompleted', models.BooleanField(db_column='isCompleted', default=False)),
                ('wallet', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.wallet')),
            ],
            options={
                'db_table': 'WalletHistories',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Verification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('username', models.CharField(blank=True, db_column='userName', max_length=255, null=True)),
                ('meansOfIdentificationId', models.IntegerField(blank=True, db_column='meansOfIdentificationId', null=True)),
                ('meansOfIdentificationName', models.CharField(blank=True, db_column='meansOfIdentificationName', max_length=255, null=True)),
                ('active', models.BooleanField(default=False)),
                ('type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.verificationtype')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='verifications', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'Verifications',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='TransactionLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('transactionRef', models.CharField(max_length=255, unique=True)),
                ('paymentRef', models.CharField(blank=True, db_column='paymentRef', max_length=255, null=True)),
                ('serviceDescription', models.TextField(blank=True, db_column='serviceDescription', null=True)),
                ('platform', models.CharField(blank=True, max_length=30, null=True)),
                ('requestJson', models.JSONField(blank=True, db_column='requestJSON', null=True)),
                ('responseJson', models.JSONField(blank=True, db_column='responseJSON', null=True)),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('isPaid', models.BooleanField(default=False)),
                ('status', models.CharField(blank=True, max_length=30, null=True)),
                ('vendorStatus', models.CharField(blank=True, max_length=30, null=True)),
                ('callbackJson', models.JSONField(blank=True, db_column='callbackJSON', null=True)),
                ('verifyJson', models.JSONField(blank=True, db_column='verifyJSON', null=True)),
                ('webhookJson', models.JSONField(blank=True, db_column='webhookJSON', null=True)),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('email', models.EmailField(blank=True, max_length=254, null=True)),
                ('paymentType', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.paymenttype')),
                ('paymentVendor', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.paymentvendor')),
                ('recipient', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='received_transactions', to=settings.AUTH_USER_MODEL)),
                ('service', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorderservice')),
            ],
            options={
                'db_table': 'TransactionLogs',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Survey',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('responseTime', models.IntegerField(db_column='responseTime', default=0)),
                ('professionalism', models.IntegerField(default=0)),
                ('serviceQuality', models.IntegerField(db_column='serviceQuality', default=0)),
                ('review', models.TextField(blank=True, null=True)),
                ('rating', models.IntegerField(default=0)),
                ('workOrder', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder')),
            ],
            options={
                'db_table': 'Surveys',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Purchase',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('quantity', models.IntegerField(default=1)),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=12)),
                ('cart', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.cart')),
                ('product', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.product')),
            ],
            options={
                'db_table': 'Purchases',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Payment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('orderId', models.CharField(blank=True, db_column='orderId', max_length=255, null=True)),
                ('transactionRef', models.CharField(blank=True, db_column='transactionRef', max_length=255, null=True)),
                ('paymentRef', models.CharField(blank=True, db_column='paymentRef', max_length=255, null=True)),
                ('paymentJson', models.JSONField(blank=True, db_column='paymentJSON', null=True)),
                ('channel', models.CharField(blank=True, max_length=255, null=True)),
                ('paymentType', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.paymenttype')),
                ('paymentVendor', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.paymentvendor')),
                ('transactionLog', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.transactionlog')),
            ],
            options={
                'db_table': 'Payments',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='NextOfKin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('address', models.CharField(blank=True, max_length=255, null=True)),
                ('relationship', models.CharField(max_length=30)),
                ('phoneNumber', models.CharField(blank=True, db_column='phoneNumber', max_length=11, null=True)),
                ('active', models.BooleanField(default=True)),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='nextofkins', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'NextOfKins',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='MeterRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('quantity', models.IntegerField(default=1)),
                ('phone', models.CharField(blank=True, max_length=11, null=True)),
                ('account', models.CharField(blank=True, max_length=255, null=True)),
                ('address', models.TextField(blank=True, null=True)),
                ('disco', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.disco')),
            ],
            options={
                'db_table': 'MeterRequests',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message', models.TextField()),
                ('type', models.CharField(max_length=30)),
                ('conversation', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='messages', to='app.conversation')),
                ('sender', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='messages', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'Messages',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Expertise',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
                ('active', models.BooleanField(blank=True, null=True)),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='expertises', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'Expertises',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Documentation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField(blank=True, null=True)),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='documentations', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'Documentations',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reference', models.CharField(blank=True, max_length=255, null=True)),
                ('filename', models.CharField(blank=True, db_column='fileName', max_length=255, null=True)),
                ('type', models.CharField(blank=True, max_length=30, null=True)),
                ('workOrder', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder')),
            ],
            options={
                'db_table': 'Documents',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
        migrations.CreateModel(
            name='Card',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('signature', models.CharField(blank=True, max_length=255, null=True)),
                ('email', models.CharField(blank=True, max_length=255, null=True)),
                ('authorization', models.JSONField(blank=True, null=True)),
                ('paymentVendor', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.paymentvendor')),
            ],
            options={
                'db_table': 'Cards',
            },
            #bases=(models.Model, mojec_core.app.models.base.BaseModelAbstract),
        ),
    ]



# Generated by Django 3.2.7 on 2022-06-14 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0004_auto_20220614_0619'),
    ]

    operations = [
        migrations.AlterField(
            model_name='workorder',
            name='generalStatus',
            field=models.CharField(blank=True, db_column='generalStatus', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='paymentJson',
            field=models.JSONField(blank=True, db_column='paymentJson', null=True),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='transactionReference',
            field=models.TextField(blank=True, db_column='transactionReference', max_length=255, null=True),
        ),
    ]



from django.db import models
from .base import BaseModelAbstract
from .work_order import WorkOrder


class WorkOrderStatus(BaseModelAbstract, models.Model):
    workOrder = models.ForeignKey(
        WorkOrder,
        on_delete=models.SET_NULL,
        blank=True, null=True
    )
    status = models.CharField(max_length=50, blank=True, null=True)
    currentStatus = models.BooleanField(
        db_column='currentStatus', default=True
    )
    description = models.TextField(blank=True, null=True)

    class Meta:
        db_table = 'WorkOrderStatuses'



# Generated by Django 3.2.7 on 2022-06-26 15:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0011_auto_20220626_1643'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='workorder',
            name='paymentJson',
        ),
        migrations.AddField(
            model_name='workorder',
            name='latitude',
            field=models.CharField(default='0', max_length=30),
        ),
        migrations.AddField(
            model_name='workorder',
            name='longitude',
            field=models.CharField(default='0', max_length=30),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='address',
            field=models.TextField(default=''),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='workorder',
            name='agentArrived',
            field=models.BooleanField(db_column='agentArrived', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='agentEnroute',
            field=models.BooleanField(db_column='agentEnroute', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='currentStatus',
            field=models.CharField(db_column='currentStatus', default='unAssigned', max_length=30),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='customerCompletionConfirmation',
            field=models.BooleanField(db_column='customerCompletionConfirmation', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='isAssessmentCompleted',
            field=models.BooleanField(db_column='isAssessmentCompleted', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='isCommitmentFeePaid',
            field=models.BooleanField(db_column='isCommitmentFeePaid', default=False),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='paymentCompleted',
            field=models.BooleanField(db_column='paymentCompleted', default=False),
        ),
    ]



from typing import Optional

from onesignal_sdk.client import Client
from onesignal_sdk.error import OneSignalHTTPError

from mojec_core import settings
from mojec_core.utils import log_exception


class PushNotificationManager:
    client = Client(app_id=settings.ONE_SIGNAL_APP_ID,
                    rest_api_key=settings.ONE_SIGNAL_REST_API_KEY,
                    user_auth_key=settings.ONE_SIGNAL_USER_AUTH_KEY)

    def send(self, msg, data=None, uid=None, user: Optional = None):
        from mojec_core.app.models import User
        """
        For sending push notification to all user devices
        by passing either uid or user object

        :param msg: The text to be sent as notification content
        :param data: data to be sent along with the notification
        :param uid: can be user.id or user.uid.
        :param user:
        :return:
        """
        try:
            if uid:
                if '-' in uid:
                    user = User.objects.get(uid=uid)
                else:
                    user = User.objects.get(id=uid)
            include_player_ids = user.fcmToken
            if bool(include_player_ids):
                notification_body = {
                    'contents': {'en': msg},
                    'data': data,
                    'include_player_ids': include_player_ids
                }

                # Make a request to OneSignal and parse response
                response = self.client.send_notification(notification_body)
                print("---------PushNotificationManager-------------")
                print(response.body)  # JSON parsed response
                print("---------/PushNotificationManager/-------------")

        except OneSignalHTTPError as e:  # An exception is raised if
            # response.status_code != 2xx
            log_exception("PushNotificationManager", e)
        except Exception as e:
            log_exception("PushNotificationManager", e)



# Generated by Django 3.2.7 on 2022-06-14 06:19

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0003_auto_20220614_0550'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='workorderservicecategory',
            name='serviceId',
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='service',
            field=models.ForeignKey(blank=True, db_column='service', null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorderservice'),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='chargeType',
            field=models.CharField(blank=True, db_column='chargeType', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='name',
            field=models.CharField(default=django.utils.timezone.now, max_length=255),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.7 on 2022-07-04 16:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0014_meterrequest_orderid'),
    ]

    operations = [
        migrations.AddField(
            model_name='meterrequest',
            name='status',
            field=models.CharField(default='new', max_length=15),
        ),
    ]



from django.db import models
from .base import BaseModelAbstract


class PaymentVendor(BaseModelAbstract, models.Model):
    type = models.CharField(max_length=30, blank=True, null=True)
    name = models.CharField(max_length=30, blank=True, null=True)
    accountNo = models.CharField(db_column='accountNo', max_length=255,
                                 blank=True, null=True)
    accountName = models.CharField(db_column='accountName',
                                   max_length=255, blank=True, null=True)
    ref = models.CharField(max_length=30, blank=True, null=True)
    logo = models.CharField(max_length=255, blank=True, null=True)

    class Meta:
        db_table = 'PaymentVendors'

#
# class Payment(BaseModelAbstract, models.Model):
#     orderId = models.CharField(db_column='orderId', max_length=255,
#                                blank=True,
#                                null=True)  # Field name made lowercase.
#     transactionRef = models.CharField(
#         db_column='transactionRef', max_length=255, blank=True, null=True)
#     paymentRef = models.CharField(db_column='paymentRef', max_length=255,
#                                   blank=True, null=True)
#     transactionLog = models.ForeignKey(TransactionLog, models.SET_NULL,
#                                        blank=True, null=True)
#     paymentVendor = models.ForeignKey(PaymentVendor, models.SET_NULL,
#                                       blank=True, null=True)
#     # paymentType = models.ForeignKey(PaymentType, models.SET_NULL,
#     #                                 blank=True, null=True)
#     paymentJson = models.JSONField(db_column='paymentJSON', blank=True,
#                                    null=True)  # Field name made lowercase.
#     channel = models.CharField(max_length=255, blank=True, null=True)
#
#     class Meta:
#         db_table = 'Payments'
#



from django.db import models
from mojec_core.app.models import BaseModelAbstract


class PowerVend(BaseModelAbstract, models.Model):
    meter_number = models.CharField(max_length=250)
    red_code = models.CharField(max_length=250)
    amount = models.DecimalField(max_digits=15, decimal_places=2, default=0)
    status = models.CharField(max_length=30, default='new', blank=True,
                              null=True)
    token = models.CharField(max_length=250)
    action = models.CharField(max_length=250)

    class Meta:
        db_table = 'PowerVend'



# Generated by Django 3.2.7 on 2022-06-25 00:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0009_auto_20220624_2026'),
    ]

    operations = [
        migrations.AlterField(
            model_name='config',
            name='service',
            field=models.CharField(choices=[('msh', 'msh'), ('payment', 'payment'), ('inventory', 'inventory'), ('customer', 'customer')], max_length=50),
        ),
    ]



from django.db.models.signals import post_save, post_delete
from django.dispatch import receiver

from .managers.config_manager import ConfigManager
from .models import Config

__all__ = ['config_update_hook', 'config_delete_hook']


@receiver(post_save, sender=Config)
def config_update_hook(sender, instance, **kwargs):
    config_manager = ConfigManager(instance.service)
    config_manager.store(instance.key, instance.value)


@receiver(post_delete, sender=Config)
def config_delete_hook(sender, instance, **kwargs):
    config_manager = ConfigManager(instance.service)
    config_manager.delete(instance.key, instance.value)



from django.db import models

from . import Product
from .work_order import WorkOrder
from .base import BaseModelAbstract


class WorkOrderMaterial(BaseModelAbstract, models.Model):
    workOrder = models.ForeignKey(WorkOrder, on_delete=models.SET_NULL,
                                  null=True, blank=True)
    product = models.ForeignKey(Product, null=True, blank=True,
                                on_delete=models.CASCADE)
    quantity = models.IntegerField(default=1)
    price = models.DecimalField(max_digits=15, decimal_places=2, default=0)
    total = models.DecimalField(max_digits=15, decimal_places=2, default=0)

    class Meta:
        db_table = 'WorkOrderMaterials'




from django.db import models

from .base import BaseModelAbstract
from .user import User


class NextOfKin(BaseModelAbstract, models.Model):
    name = models.CharField(max_length=255, blank=False, null=False)
    user = models.ForeignKey(User, models.CASCADE, blank=True, null=True, 
                             related_name="nextofkins")
    address = models.CharField(max_length=255, blank=True, null=True)
    relationship = models.CharField(max_length=30, blank=False, null=False)
    phoneNumber = models.CharField(db_column='phoneNumber', max_length=11,
                                   blank=True, null=True)
    active = models.BooleanField(default=True)

    class Meta:
        db_table = 'NextOfKins'



# Generated by Django 3.2.7 on 2022-06-23 03:23

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0007_auto_20220617_2252'),
    ]

    operations = [
        migrations.CreateModel(
            name='Config',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('service', models.CharField(choices=[('msh', 'msh'), ('payment', 'payment'), ('inventory', 'inventory'), ('customer', 'customer')], max_length=50, unique=True)),
                ('key', models.CharField(max_length=50, unique=True)),
                ('value', models.CharField(max_length=100)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
                ('last_updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.RemoveField(
            model_name='payment',
            name='paymentType',
        ),
        migrations.RemoveField(
            model_name='paymentvendor',
            name='credential',
        ),
        migrations.RemoveField(
            model_name='paymentvendor',
            name='paths',
        ),
        migrations.RemoveField(
            model_name='paymentvendor',
            name='url',
        ),
        migrations.RemoveField(
            model_name='transactionlog',
            name='paymentType',
        ),
        migrations.RemoveField(
            model_name='workorder',
            name='paymentType',
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='name',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='ref',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='paymentvendor',
            name='type',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
        migrations.DeleteModel(
            name='PaymentType',
        ),
    ]



from django.db import models

from .base import BaseModelAbstract
from .user import User


class UserAddress(BaseModelAbstract, models.Model):
    title = models.CharField(max_length=100, null=False, blank=False)
    text = models.TextField(null=False, blank=False)



from django.db import models
from .base import BaseModelAbstract


class Cart(BaseModelAbstract, models.Model):
    totalAmount = models.DecimalField(db_column='totalAmount',
                                      max_digits=15, decimal_places=2,
                                      default=0)
    status = models.TextField(blank=True, null=True)
    transactionRef = models.CharField(db_column='transactionRef',
                                      max_length=255, blank=True,
                                      null=True)
    deliveryAddress = models.TextField(db_column='deliveryAddress',
                                       blank=True, null=True)

    class Meta:
        db_table = 'Carts'




from django.db import models

from .base import BaseModelAbstract
from .user import User


class Conversation(BaseModelAbstract, models.Model):
    user1 = models.ForeignKey(
        User, models.SET_NULL, related_name="chat_user1_set",
        null=True, blank=True
    )
    user2 = models.ForeignKey(
        User, models.SET_NULL, related_name="chat_user2_set",
        null=True, blank=True
    )

    class Meta:
        db_table = 'Conversations'


class Message(BaseModelAbstract, models.Model):
    conversation = models.ForeignKey(Conversation, models.DO_NOTHING,
                                     blank=True, null=True,
                                     related_name="messages")
    sender = models.ForeignKey(User, models.SET_NULL, related_name="messages",
                               blank=True, null=True)
    message = models.TextField(blank=False, null=False)
    type = models.CharField(max_length=30, blank=False, null=False)

    class Meta:
        db_table = 'Messages'



import os, sys

from dotenv import load_dotenv
from datetime import timedelta
import firebase_admin
from firebase_admin import credentials

from pathlib import Path
PACKAGE_DIR = Path(__file__).resolve().parent

load_dotenv()

AUTH_USER_MODEL = 'app.User'

SECRET_KEY = 'da)(@*#Uhubjindu*(!@#$#@nfoinond-ahp*nen2@=*u)!g8m9pthdg'

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    "corsheaders.middleware.CorsMiddleware",
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]


def db(key):
    return os.getenv(key)

# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases


if 'test' in sys.argv:
    DATABASES = {
        'default': {
            'ENGINE': "django.db.backends.sqlite3",
            'NAME': "test.db"
        }
    }
else:
    DATABASES = {
        'default': {
            'ENGINE': db("DB_ENGINE"),
            'NAME': db('POSTGRES_DB'),
            'USER': db('POSTGRES_USER'),
            'PASSWORD': db('POSTGRES_PASSWORD'),
            'HOST': db('DB_HOST'),
            'PORT': db('DB_PORT'),
        }
    }


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'Africa/Lagos'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'standard': {
            'format': '[%(levelname)s] %(asctime)s %(name)s: %(message)s'
        },
    },
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'standard',
        },
    },
    'root': {
        'handlers': ['console', ],
        'level': 'DEBUG'
    },
    'loggers': {
        'django.request': {
            'handlers': [
                'console',
            ],
            'level': 'DEBUG',
            'propagate': False
        },
    }
}
SAFE_DELETE_FIELD_NAME = "deletedAt"
SAFE_DELETE_CASCADED_FIELD_NAME = "deletedViaCascade"
REST_FRAMEWORK = {
    'DEFAULT_PAGINATION_CLASS': 'rest_framework.pagination.PageNumberPagination',
    'PAGE_SIZE': 15,
    'PAGINATE_BY_PARAM': 'limit',
    'DEFAULT_AUTHENTICATION_CLASSES': (
        'rest_framework_simplejwt.authentication.JWTAuthentication',
    )
}


SIMPLE_JWT = {
    'ACCESS_TOKEN_LIFETIME': timedelta(hours=12),
    'REFRESH_TOKEN_LIFETIME': timedelta(days=7),
    'ROTATE_REFRESH_TOKENS': False,
    'BLACKLIST_AFTER_ROTATION': False,
    'UPDATE_LAST_LOGIN': False,

    'ALGORITHM': 'HS256',
    'SIGNING_KEY': SECRET_KEY,
    'VERIFYING_KEY': None,
    'AUDIENCE': None,
    'ISSUER': None,
    'JWK_URL': None,
    'LEEWAY': 0,

    'AUTH_HEADER_TYPES': ('Bearer',),
    'AUTH_HEADER_NAME': 'HTTP_AUTHORIZATION',
    'USER_ID_FIELD': 'uid',
    'USER_ID_CLAIM': 'uid',
    'USER_AUTHENTICATION_RULE': 'rest_framework_simplejwt.authentication.default_user_authentication_rule',

    'AUTH_TOKEN_CLASSES': ('rest_framework_simplejwt.tokens.AccessToken',),
    'TOKEN_TYPE_CLAIM': 'token_type',
    'TOKEN_USER_CLASS': 'rest_framework_simplejwt.models.TokenUser',

    'JTI_CLAIM': 'jti',

    'SLIDING_TOKEN_REFRESH_EXP_CLAIM': 'refresh_exp',
    'SLIDING_TOKEN_LIFETIME': timedelta(hours=12),
    'SLIDING_TOKEN_REFRESH_LIFETIME': timedelta(days=7),
}

CORS_ALLOW_ALL_ORIGINS = True
REDIS_CONFIG_KEY = "CONFIGURATIONS"


firebase_credentials = credentials.Certificate(PACKAGE_DIR / "firebase.json")
firebase_admin.initialize_app(firebase_credentials)

ONE_SIGNAL_APP_ID = "8bf62455-7eb2-46fb-84a3-c4a3e99d1b61"
ONE_SIGNAL_REST_API_KEY = "MzliODFkZGUtYmRmZS00OGE1LThmM2MtYWVjNDU3ZjM5ZTA0"
ONE_SIGNAL_USER_AUTH_KEY = "MzliODFkZGUtYmRmZS00OGE1LThmM2MtYWVjNDU3ZjM5ZTA0"



# Generated by Django 3.2.7 on 2022-06-15 07:14

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0005_auto_20220614_1601'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='locationLatitude',
            field=models.FloatField(default=0),
        ),
        migrations.AddField(
            model_name='user',
            name='locationLongitude',
            field=models.FloatField(default=0),
        ),
        migrations.AddField(
            model_name='workorder',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorder',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorder',
            name='currentStatus',
            field=models.CharField(db_column='currentStatus', default='unPaid', max_length=30),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='deletedViaCascade',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AddField(
            model_name='workorder',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorder',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AlterField(
            model_name='workorder',
            name='generalStatus',
            field=models.CharField(db_column='generalStatus', default='new', max_length=30),
        ),
    ]



from collections import Counter
from collections import defaultdict
from itertools import chain
import warnings

import django
from django.contrib.admin.utils import NestedObjects
from django.db import models, router
from django.db.models import UniqueConstraint
from django.db.models.deletion import ProtectedError
from django.utils import timezone

from safedelete.config import (
    FIELD_NAME,
    HARD_DELETE,
    HARD_DELETE_NOCASCADE,
    DELETED_BY_CASCADE_FIELD_NAME,
    NO_DELETE,
    SOFT_DELETE,
    SOFT_DELETE_CASCADE,
)
from safedelete.managers import (
    SafeDeleteAllManager,
    SafeDeleteDeletedManager,
    SafeDeleteManager,
)
from safedelete.signals import post_softdelete, post_undelete, pre_softdelete
from safedelete.utils import can_hard_delete, related_objects


def is_safedelete_cls(cls):
    for base in cls.__bases__:
        # This used to check if it startswith 'safedelete', but that masks
        # the issue inside of a test. Other clients create models that are
        # outside of the safedelete package.
        if base.__module__.startswith('safedelete.models'):
            return True
        if is_safedelete_cls(base):
            return True
    return False


def is_safedelete(related):
    warnings.warn(
        'is_safedelete is deprecated in favor of is_safedelete_cls',
        DeprecationWarning)
    return is_safedelete_cls(related.__class__)


class SafeDeleteModel:
    """Abstract safedelete-ready model.

    .. note::
        To create your safedelete-ready models, you have to make them inherit from this model.

    :attribute deleted:
        DateTimeField set to the moment the object was deleted. Is set to
        ``None`` if the object has not been deleted.

    :attribute deleted_by_cascade:
        BooleanField set True whenever the object is deleted due cascade operation called by delete
        method of any parent Model. Default value is False. Later if its parent model calls for
        cascading undelete, it will restore only child classes that were also deleted by a cascading
        operation (deleted_by_cascade equals to True), i.e. all objects that were deleted before their
        parent deletion, should keep deleted if the same parent object is restored by undelete method.

        If this behavior isn't desired, class that inherits from SafeDeleteModel can override this
        attribute by setting it as None: overriding model class won't have its ``deleted_by_cascade``
        field and won't be restored by cascading undelete even if it was deleted by a cascade operation.

        >>> class MyModel(SafeDeleteModel):
        ...     deleted_by_cascade = None
        ...     my_field = models.TextField()

    :attribute _safedelete_policy: define what happens when you delete an object.
        It can be one of ``HARD_DELETE``, ``SOFT_DELETE``, ``SOFT_DELETE_CASCADE``, ``NO_DELETE`` and ``HARD_DELETE_NOCASCADE``.
        Defaults to ``SOFT_DELETE``.

        >>> class MyModel(SafeDeleteModel):
        ...     _safedelete_policy = SOFT_DELETE
        ...     my_field = models.TextField()
        ...
        >>> # Now you have your model (with its ``deleted`` field, and custom manager and delete method)

    :attribute objects:
        The :class:`safedelete.managers.SafeDeleteManager` returns the non-deleted models.

    :attribute all_objects:
        The :class:`safedelete.managers.SafeDeleteAllManager` returns all the models (non-deleted and soft-deleted).

    :attribute deleted_objects:
        The :class:`safedelete.managers.SafeDeleteDeletedManager` returns the soft-deleted models.
    """

    _safedelete_policy = SOFT_DELETE_CASCADE

    deleted = models.BooleanField(null=True, blank=True, default=None)
    deletedViaCascade = models.BooleanField(null=True, blank=True,
                                            default=None)

    objects = SafeDeleteManager()
    all_objects = SafeDeleteAllManager()
    deleted_objects = SafeDeleteDeletedManager()

    def save(self, keep_deleted=False, **kwargs):
        """Save an object, un-deleting it if it was deleted.

        Args:
            keep_deleted: Do not undelete the model if soft-deleted. (default: {False})
            kwargs: Passed onto :func:`save`.

        .. note::
            Undeletes soft-deleted models by default.
        """

        # undelete signal has to happen here (and not in undelete)
        # in order to catch the case where a deleted model becomes
        # implicitly undeleted on-save.  If someone manually nulls out
        # deleted, it'll bypass this logic, which I think is fine, because
        # otherwise we'd have to shadow field changes to handle that case.

        was_undeleted = False
        if not keep_deleted:
            if getattr(self, FIELD_NAME) and self.pk:
                was_undeleted = True
            setattr(self, FIELD_NAME, None)
            setattr(self, DELETED_BY_CASCADE_FIELD_NAME, False)

        super(SafeDeleteModel, self).save(**kwargs)

        if was_undeleted:
            # send undelete signal
            using = kwargs.get('using') or router.db_for_write(self.__class__, instance=self)
            post_undelete.send(sender=self.__class__, instance=self, using=using)

    def undelete(self, force_policy=None, **kwargs):
        """Undelete a soft-deleted model.

        Args:
            force_policy: Force a specific undelete policy. (default: {None})
            kwargs: Passed onto :func:`save`.

        .. note::
            Will raise a :class:`AssertionError` if the model was not soft-deleted.
        """
        current_policy = force_policy or self._safedelete_policy

        assert getattr(self, FIELD_NAME)
        self.save(keep_deleted=False, **kwargs)
        undeleted_counter = Counter({self._meta.label: 1})

        if current_policy == SOFT_DELETE_CASCADE:
            for related in related_objects(self, only_deleted_by_cascade=True):
                if is_safedelete_cls(related.__class__) and getattr(related, FIELD_NAME):
                    _, undelete_response = related.undelete(**kwargs)
                    undeleted_counter.update(undelete_response)

        return sum(undeleted_counter.values()), dict(undeleted_counter)

    def delete(self, force_policy=None, **kwargs):
        # To know why we need to do that, see https://github.com/makinacorpus/django-safedelete/issues/117
        return self._delete(force_policy, **kwargs)

    def _delete(self, force_policy=None, **kwargs):
        """Overrides Django's delete behaviour based on the model's delete policy.

        Args:
            force_policy: Force a specific delete policy. (default: {None})
            kwargs: Passed onto :func:`save` if soft deleted.
        """
        current_policy = self._safedelete_policy if (force_policy is None) else force_policy

        if current_policy == NO_DELETE:
            return (0, {})
        elif current_policy == SOFT_DELETE:
            return self.soft_delete_policy_action(**kwargs)
        elif current_policy == HARD_DELETE:
            return self.hard_delete_policy_action(**kwargs)
        elif current_policy == HARD_DELETE_NOCASCADE:
            return self.hard_delete_cascade_policy_action(**kwargs)
        elif current_policy == SOFT_DELETE_CASCADE:
            return self.soft_delete_cascade_policy_action(**kwargs)

    def soft_delete_policy_action(self, **kwargs):
        # Only soft-delete the object, marking it as deleted.
        setattr(self, FIELD_NAME, timezone.now())

        # is_cascade shouldn't be in kwargs when calling save method.
        if kwargs.pop('is_cascade', False):
            setattr(self, DELETED_BY_CASCADE_FIELD_NAME, True)

        using = kwargs.get('using') or router.db_for_write(self.__class__, instance=self)
        # send pre_softdelete signal
        pre_softdelete.send(sender=self.__class__, instance=self, using=using)
        self.save(keep_deleted=True, **kwargs)
        # send softdelete signal
        post_softdelete.send(sender=self.__class__, instance=self, using=using)

        return (1, {self._meta.label: 1})

    def hard_delete_policy_action(self, **kwargs):
        # Normally hard-delete the object.
        return super(SafeDeleteModel, self).delete()

    def hard_delete_cascade_policy_action(self, **kwargs):
        # Hard-delete the object only if nothing would be deleted with it
        if not can_hard_delete(self):
            return self._delete(force_policy=SOFT_DELETE, **kwargs)
        else:
            return self._delete(force_policy=HARD_DELETE, **kwargs)

    def soft_delete_cascade_policy_action(self, **kwargs):
        collector = NestedObjects(using=router.db_for_write(self))
        collector.collect([self])
        # Soft-delete-cascade raises an exception when trying to delete a object that related object is PROTECT
        protected_objects = defaultdict(list)
        for obj in collector.protected:
            if getattr(obj, FIELD_NAME, None) is None:
                protected_objects[obj.__class__.__name__].append(obj)
        if protected_objects:
            raise ProtectedError(
                'Cannot delete some instances of model %r because they are '
                'referenced through protected foreign keys: %s.' % (
                    self.__class__.__name__,
                    ', '.join(protected_objects),
                ),
                set(chain.from_iterable(protected_objects.values())),
            )

        # Soft-delete on related objects before
        deleted_counter = Counter()
        for related in related_objects(self):
            if is_safedelete_cls(related.__class__) and not getattr(related, FIELD_NAME):
                _, delete_response = related.delete(force_policy=SOFT_DELETE, is_cascade=True, **kwargs)
                deleted_counter.update(delete_response)

        # soft-delete the object
        _, delete_response = self._delete(force_policy=SOFT_DELETE, **kwargs)
        deleted_counter.update(delete_response)

        # update fields (SET, SET_DEFAULT or SET_NULL)
        for model, instances_for_fieldvalues in collector.field_updates.items():
            for (field, value), instances in instances_for_fieldvalues.items():
                query = models.sql.UpdateQuery(model)
                query.update_batch(
                    [obj.pk for obj in instances],
                    {field.name: value},
                    collector.using,
                )

        return sum(deleted_counter.values()), dict(deleted_counter)

    @classmethod
    def has_unique_fields(cls):
        """Checks if one of the fields of this model has a unique constraint set (unique=True).

        It also checks if the model has sets of field names that, taken together, must be unique.

        Args:
            model: Model instance to check
        """
        if cls._meta.unique_together:
            return True

        if django.VERSION[0] > 3 or (django.VERSION[0] == 3 and django.VERSION[1] >= 1):
            if cls._meta.total_unique_constraints:
                return True
        else:  # derived from total_unique_constraints in django >= 3.1
            for constraint in cls._meta.constraints:
                if isinstance(constraint, UniqueConstraint) and constraint.condition is None:
                    return True

        for field in cls._meta.fields:
            if field._unique:
                return True
        return False

    # We need to overwrite this check to ensure uniqueness is also checked
    # against "deleted" (but still in db) objects.
    # FIXME: Better/cleaner way ?
    def _perform_unique_checks(self, unique_checks):
        errors = {}

        for model_class, unique_check in unique_checks:
            lookup_kwargs = {}
            for field_name in unique_check:
                f = self._meta.get_field(field_name)
                lookup_value = getattr(self, f.attname)
                if lookup_value is None:
                    continue
                if f.primary_key and not self._state.adding:
                    continue
                lookup_kwargs[str(field_name)] = lookup_value
            if len(unique_check) != len(lookup_kwargs):
                continue

            # This is the changed line
            if hasattr(model_class, 'all_objects'):
                qs = model_class.all_objects.filter(**lookup_kwargs)
            else:
                qs = model_class._default_manager.filter(**lookup_kwargs)

            model_class_pk = self._get_pk_val(model_class._meta)
            if not self._state.adding and model_class_pk is not None:
                qs = qs.exclude(pk=model_class_pk)
            if qs.exists():
                if len(unique_check) == 1:
                    key = unique_check[0]
                else:
                    key = models.base.NON_FIELD_ERRORS
                errors.setdefault(key, []).append(
                    self.unique_error_message(model_class, unique_check)
                )
        return errors





from django.db import models

from .base import BaseModelAbstract
from .work_order import WorkOrder


class Survey(BaseModelAbstract, models.Model):
    workOrder = models.ForeignKey(WorkOrder, models.SET_NULL,
                                  blank=True, null=True)
    responseTime = models.IntegerField(db_column='responseTime', default=0)
    professionalism = models.IntegerField(default=0)
    serviceQuality = models.IntegerField(db_column='serviceQuality',
                                         default=0)
    review = models.TextField(blank=True, null=True)
    rating = models.IntegerField(default=0)

    class Meta:
        db_table = 'Surveys'





from django.db import models

from .base import BaseModelAbstract


class Disco(BaseModelAbstract, models.Model):
    longName = models.CharField(max_length=255, blank=False, null=False)
    shortName = models.CharField(max_length=10, blank=False, null=False)
    location = models.TextField(blank=True, null=True)
    status = models.CharField(max_length=30, blank=True, null=True)

    class Meta:
        db_table = 'Discos'


class BusinessUnit(BaseModelAbstract, models.Model):
    disco = models.ForeignKey(Disco, models.CASCADE,
                              related_name="business_units")
    name = models.CharField(max_length=255, blank=False, null=False)
    location = models.TextField(blank=True, null=True)
    status = models.CharField(max_length=30, blank=True, null=True)

    class Meta:
        db_table = 'BusinessUnits'



# Generated by Django 3.2.7 on 2022-06-28 17:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0012_auto_20220626_1653'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='wallet',
            name='name',
        ),
        migrations.RemoveField(
            model_name='wallet',
            name='recipient',
        ),
        migrations.RemoveField(
            model_name='wallet',
            name='recipientCode',
        ),
        migrations.RemoveField(
            model_name='wallethistory',
            name='isCompleted',
        ),
        migrations.RemoveField(
            model_name='wallethistory',
            name='requestJson',
        ),
        migrations.RemoveField(
            model_name='wallethistory',
            name='transferCode',
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='balanceAfter',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=15),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='balanceBefore',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=15),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='isSuccessful',
            field=models.BooleanField(db_column='isSuccessful', default=False),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='transactionLog',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.transactionlog'),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='workOrder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder'),
        ),
        migrations.AlterField(
            model_name='wallethistory',
            name='type',
            field=models.CharField(blank=True, choices=[('earnings', 'earnings'), ('deposit', 'deposit'), ('withdrawal', 'withdrawal')], max_length=30, null=True),
        ),
        migrations.DeleteModel(
            name='Earning',
        ),
    ]



from django.conf import settings

from .base_redis_manager import BaseRedisManager


class ConfigManager(BaseRedisManager):
    def __init__(self, service):
        super().__init__(
            f"{service}_{settings.REDIS_CONFIG_KEY}".upper()
        )
        if self.client is None:
            self.connect()

    def load(self):
        keys_ = self.client.hgetall(self.config_store)
        print("keys", keys_)
        values_ = self.client.hvals(self.config_store)
        all_keys = [x.decode('utf8') for x in keys_]
        all_values = [y.decode('utf8') for y in values_]
        config = dict()
        len_keys = len(all_keys)
        for index in range(len_keys):
            config.update({all_keys[index]: all_values[index]})

        print("Config loaded", config, sep='\n')
        return config

    def store(self, key, value):
        self.client.hset(self.config_store, key, value)

    def delete(self, key, value):
        self.client.hdel(self.config_store, key, value)
    
    def updateApiCall(self, daily_key):
        return self.client.hincrby(daily_key, "Request")
    
    def updateApiCallRequest(self, daily_key, msisdn):
        return self.client.lpush(daily_key, msisdn)




# Generated by Django 3.2.7 on 2022-06-14 04:56

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='card',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='card',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='card',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='card',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='cart',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='cart',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='cart',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='cart',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='cart',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='conversation',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='conversation',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='conversation',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='conversation',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='disco',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='disco',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='disco',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='disco',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='disco',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='document',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='document',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='document',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='document',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='document',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='documentation',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='documentation',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='documentation',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='documentation',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='expertise',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='expertise',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='expertise',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='expertise',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='meansofidentification',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='message',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='message',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='message',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='message',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='nextofkin',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='payment',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='payment',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='payment',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='payment',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='paymenttype',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='paymentvendor',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='product',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='product',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='product',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='product',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='purchase',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='purchase',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='purchase',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='purchase',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='survey',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='survey',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='survey',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='survey',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='survey',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='user',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='user',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='user',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='user',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='useraddress',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='useraddress',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='verification',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='verification',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='verification',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verification',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='verification',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='verificationtype',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='wallet',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='wallet',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallet',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='wallet',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='wallethistory',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorderservice',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='createdAt',
            field=models.DateTimeField(auto_now_add=True, db_column='createdAt', default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='createdBy',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deleted',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deletedAt',
            field=models.DateTimeField(blank=True, db_column='deletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deletedById',
            field=models.UUIDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='deletedViaCascade',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='uid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name='workorderstatus',
            name='updatedAt',
            field=models.DateTimeField(auto_now=True, db_column='updatedAt'),
        ),
        migrations.AlterField(
            model_name='conversation',
            name='participants',
            field=models.ManyToManyField(related_name='conversations', to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 3.2.7 on 2022-07-17 21:10

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0017_auto_20220714_0637'),
    ]

    operations = [
        migrations.RenameField(
            model_name='workorder',
            old_name='fee',
            new_name='commission',
        ),
        migrations.RemoveField(
            model_name='workorder',
            name='jobCompletedAt',
        ),
        migrations.RemoveField(
            model_name='workorder',
            name='remainingServiceCharge',
        ),
        migrations.RemoveField(
            model_name='workordermaterial',
            name='description',
        ),
        migrations.RemoveField(
            model_name='workordermaterial',
            name='item',
        ),
        migrations.RemoveField(
            model_name='workordermaterial',
            name='productName',
        ),
        migrations.AddField(
            model_name='workorder',
            name='assessmentCompletedAt',
            field=models.DateTimeField(blank=True, db_column='assessmentCompletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='jobCompletedByAgentAt',
            field=models.DateTimeField(blank=True, db_column='jobCompletedByAgentAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='jobCompletedByCustomerAt',
            field=models.DateTimeField(blank=True, db_column='jobCompletedByCustomerAt', null=True),
        ),
        migrations.AddField(
            model_name='workorder',
            name='paymentCompletedAt',
            field=models.DateTimeField(blank=True, db_column='paymentCompletedAt', null=True),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='product',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='app.product'),
        ),
        migrations.AddField(
            model_name='workordermaterial',
            name='total',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=15),
        ),
        migrations.AddField(
            model_name='workorderservicecategory',
            name='minimumServiceCharge',
            field=models.DecimalField(db_column='minimumServiceCharge', decimal_places=2, default=1, max_digits=15),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='chargeType',
            field=models.CharField(choices=[('fixed', 'fixed'), ('percent', 'percent')], db_column='chargeType', default='fixed', max_length=15),
        ),
        migrations.AlterField(
            model_name='workorderservicecategory',
            name='serviceCharge',
            field=models.DecimalField(db_column='serviceCharge', decimal_places=2, default=1, max_digits=15),
        ),
    ]



from django.db import models

from .base import BaseModelAbstract
from .user import User


class VerificationType(BaseModelAbstract, models.Model):
    name = models.CharField(max_length=255, blank=True, null=True)
    active = models.BooleanField(blank=True, null=True)

    class Meta:
        db_table = 'VerificationTypes'


class Verification(BaseModelAbstract, models.Model):
    type = models.ForeignKey(VerificationType, models.SET_NULL,
                             blank=True, null=True)
    user = models.ForeignKey(User, models.SET_NULL, blank=True, null=True, 
                             related_name="verifications")
    username = models.CharField(db_column='userName', max_length=255,
                                blank=True, null=True)
    meansOfIdentificationId = models.IntegerField(
        db_column='meansOfIdentificationId', blank=True, null=True
    )
    meansOfIdentificationName = models.CharField(
        db_column='meansOfIdentificationName', max_length=255, blank=True,
        null=True
    )
    active = models.BooleanField(default=False)

    class Meta:
        db_table = 'Verifications'







from .card import *
from .cart import *
from .chat import *
from .disco import *
from .document import *
from .expertise import *
from .means_of_identification import *
from .meter_request import *
from .next_of_kin import *
from .payment import *
from .product import *
from .purchase import *
from .survey import *
from .transaction import *
from .user import *
from .user_address import *
from .verification import *
from .wallet import *
from .work_order import *
from .work_order_material import *
from .work_order_service import *
from .work_order_status import *
from .config import *
from .power_vend import *



from django.db import models
from .base import BaseModelAbstract
from .user import User


class Expertise(BaseModelAbstract, models.Model):
    name = models.CharField(max_length=255, blank=True, null=True)
    description = models.CharField(max_length=255, blank=True, null=True)
    active = models.BooleanField(blank=True, null=True)
    user = models.ForeignKey(User, models.SET_NULL,
                             blank=True, null=True, related_name="expertises")

    class Meta:
        db_table = 'Expertises'





# Generated by Django 3.2.7 on 2022-06-17 21:52

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0006_auto_20220615_0814'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='useraddress',
            options={'ordering': ('-createdAt',)},
        ),
        migrations.RemoveField(
            model_name='conversation',
            name='participants',
        ),
        migrations.AddField(
            model_name='conversation',
            name='user1',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='chat_user1_set', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='conversation',
            name='user2',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='chat_user2_set', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='workorder',
            name='paymentType',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.paymenttype'),
        ),
        migrations.AddField(
            model_name='workorder',
            name='paymentVendor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.paymentvendor'),
        ),
    ]



from firebase_admin import firestore

from mojec_core.utils import log_exception


class FirebaseManager:
    db = firestore.client()

    def assign_workorder(self, wo):
        try:
            doc_ref = self.db.collection('WORKORDERS').document(
                wo.uid.__str__())
            data = doc_ref.get().to_dict()
            print("data", data)
            data['status'] = 'assigned'
            doc_ref.set(data)
        except Exception as ex:
            log_exception("FirebaseManager.assign_workorder", ex)

    def remove_workorder(self, uid):
        try:
            doc_ref = self.db.collection('WORKORDERS').document(str(uid))
            doc_ref.delete()
        except Exception as ex:
            log_exception("FirebaseManager.remove_workorder", ex)
